summaryrefslogtreecommitdiff
path: root/gst-libs
diff options
context:
space:
mode:
authorOlivier CrĂȘte <olivier.crete@collabora.com>2015-06-01 18:50:14 -0400
committerOlivier CrĂȘte <olivier.crete@collabora.com>2015-06-01 18:50:14 -0400
commit10319757b46ca6de28c7bc028261d884abcfb650 (patch)
tree207d767bcafae94e32a207978701552a52e74f45 /gst-libs
parentd221108857b1b0cc42b5c720b3c29e2fba795e8c (diff)
downloadgstreamer-plugins-bad-10319757b46ca6de28c7bc028261d884abcfb650.tar.gz
aggregator: Document that the latency is in ns
Diffstat (limited to 'gst-libs')
-rw-r--r--gst-libs/gst/base/gstaggregator.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gst-libs/gst/base/gstaggregator.c b/gst-libs/gst/base/gstaggregator.c
index bd08db61c..095be739a 100644
--- a/gst-libs/gst/base/gstaggregator.c
+++ b/gst-libs/gst/base/gstaggregator.c
@@ -1591,7 +1591,7 @@ gst_aggregator_finalize (GObject * object)
/*
* gst_aggregator_set_latency_property:
* @agg: a #GstAggregator
* @latency: the new latency value.
*
* Sets the new latency value to @latency. This value is used to limit the
* amount of time a pad waits for data to appear before considering the pad
@@ -1737,7 +1737,7 @@ gst_aggregator_class_init (GstAggregatorClass * klass)
g_param_spec_int64 ("latency", "Buffer latency",
"Additional latency in live mode to allow upstream "
"to take longer to produce buffers for the current "
- "position", 0,
+ "position (in nanoseconds)", 0,
(G_MAXLONG == G_MAXINT64) ? G_MAXINT64 : (G_MAXLONG * GST_SECOND - 1),
DEFAULT_LATENCY, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
@@ -1591,7 +1591,7 @@ gst_aggregator_finalize (GObject * object)
* gst_aggregator_set_latency_property:
* @agg: a #GstAggregator
- * @latency: the new latency value.
+ * @latency: the new latency value (in nanoseconds).
*
* Sets the new latency value to @latency. This value is used to limit the